@@ -21,7 +21,7 @@
 #include "rt_defines.h"
 #include "rt_nonfinite.h"
 #include "rtwtypes.h"
-#include "omp.h"
+//#include "omp.h"
 #include "CVfast_types.h"
 
 /* Function Declarations */
